@@ -109,6 +109,11 @@ impl HasDefaultTicks for i128 {
 }
 
 impl PlotNum for i128 {
+    #[inline(always)]
+    fn is_hole(&self) -> bool {
+        false
+    }
+
     #[inline(always)]
     fn scale(&self, range: [i128; 2], max: f64) -> f64 {
         let val = *self;
@@ -216,3 +221,9 @@ impl TickLayout {
         best
     }
 }
+
+impl HasZero for i128 {
+    fn zero() -> i128 {
+        0
+    }
+}
