@@ -5,7 +5,7 @@
 /// A disconnectable number. A number that can me marked as a hole to signify that there is a disconnect in plots.
 /// See [`crate::build::crop::Croppable`]
 ///
-pub trait DiscNum: PlotNum {
+pub trait DiscNum {
     /// Create a hole value.
     fn hole() -> Self;
 }
@@ -16,10 +16,7 @@ pub trait DiscNum: PlotNum {
 ///
 pub trait PlotNum: PartialOrd + Copy + std::fmt::Debug {
     /// Is this a hole value to inject discontinuty?
-    #[inline(always)]
-    fn is_hole(&self) -> bool {
-        false
-    }
+    fn is_hole(&self) -> bool;
 
     fn scale(&self, range: [Self; 2], max: f64) -> f64;
 
@@ -56,3 +53,10 @@ pub trait BaseFmt {
     fn xdash_size(&self) -> Option<f64>;
     fn ydash_size(&self) -> Option<f64>;
 }
+
+///
+/// Signify if a number has a zero value.
+///
+pub trait HasZero {
+    fn zero() -> Self;
+}
